@@ -11,7 +11,7 @@ pub enum TopicError {
     InvalidLevel,
 }
 
-#[derive(Debug, Eq, PartialEq, Clone, Hash)]
+#[derive(Debug, Clone, Hash, Eq, PartialEq, serde::Serialize, serde::Deserialize)]
 pub enum Level {
     Normal(String),
     Metadata(String), // $SYS
@@ -108,7 +108,7 @@ macro_rules! matches {
     }};
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Hash, Eq, PartialEq, serde::Serialize, serde::Deserialize)]
 pub struct Topic(Vec<Level>);
 
 impl Topic {
@@ -250,7 +250,7 @@ impl FromStr for Topic {
     #[inline]
     fn from_str(s: &str) -> Result<Self, TopicError> {
         s.split('/')
-            .map(|level| Level::from_str(level))
+            .map(Level::from_str)
             .collect::<Result<Vec<_>, TopicError>>()
             .map(Topic)
             .and_then(
