@@ -1,8 +1,7 @@
 use std::convert::TryFrom;
 
-use futures::future::ok;
 use ntex::server;
-use ntex::util::{ByteString, Bytes};
+use ntex::util::{ByteString, Bytes, Ready};
 
 use ntex_mqtt::{v3, v5, MqttServer};
 
@@ -27,17 +26,16 @@ impl TryFrom<TestError> for v5::PublishAck {
 
 #[ntex::test]
 async fn test_simple() -> std::io::Result<()> {
-    std::env::set_var("RUST_LOG", "ntex_mqtt=trace,ntex_codec=info,ntex=trace");
-    env_logger::init();
-
     let srv = server::test_server(|| {
         MqttServer::new()
-            .v3(v3::MqttServer::new(|con: v3::Handshake<_>| {
-                ok::<_, TestError>(con.ack(St, false))
+            .v3(v3::MqttServer::new(|con: v3::Handshake| {
+                Ready::Ok::<_, TestError>(con.ack(St, false))
             })
-            .publish(|_| ok::<_, TestError>(())))
-            .v5(v5::MqttServer::new(|con: v5::Handshake<_>| ok::<_, TestError>(con.ack(St)))
-                .publish(|p: v5::Publish| ok::<_, TestError>(p.ack())))
+            .publish(|_| Ready::Ok::<_, TestError>(())))
+            .v5(v5::MqttServer::new(|con: v5::Handshake| {
+                Ready::Ok::<_, TestError>(con.ack(St))
+            })
+            .publish(|p: v5::Publish| Ready::Ok::<_, TestError>(p.ack())))
     });
 
     // connect to v5 server
